/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#ifndef DISPLAY_H_
#define DISPLAY_H_

#include <sys/select.h>

#include "defs.h"


/******************************************************************************/

// This is the basic structure for screens. Every screen class 'inherits' from
// this screen structure.  The handlers for show, delete and handle_key MAY be
// intitialized with the appropriate functions of the screen class or set to
// NULL, if no functions are defined. Setting NULL is OK, the function will
// then be ignored.
//
// The type field can be used by the class to perform some simple type checking
// on screen_T* handles passed to the class functions.
//
// obj_data can be used by the screen class to store class dependent data.
//
typedef struct screen_d
{
	unsigned int type;	// menu, status type checking magic number

	void (*update) (struct screen_d *);
	void (*delete) (struct screen_d *);
	int (*handle_key) (struct screen_d *, int);

	// This is a pointer to the context object of the 'class' which derives
	// from the screen 'class'. Th _new() function of the deriving 'class'
	// MUST initialize this pointer to its context object, otherwise
	// display_show() will crash.
	//
	void *ctx;
}
screen_t;


/******************************************************************************/

// The base structure for displays. All displays must 'derive' from this structure.
//
typedef struct display_d
{
	int (*open) (struct display_d *);	// Display open function (0 == success)
	void (*close) (struct display_d *);	// Display close function
	int (*fd) (struct display_d *);	// Display's fd (-1 if not available)
	void (*ev_handler) (struct display_d *);	// Display event handler (if needed)
	void (*show) (struct display_d *, void *, unsigned int);	// Display show function
	void (*cmd) (struct display_d *, unsigned int, void *);	// Display command handler
#define CMD_CLEAR       1
}
display_t;


/******************************************************************************/

void display_session_set(unsigned int idx);
unsigned int display_session_idx();

void display_push(screen_t * screen);
void display_pop();
screen_t *display_current_screen();

void display_open();
void display_close();
void display_show();
void display_cmd(unsigned int cmd, void *arg);
int display_fds(fd_set * fds);
void display_handle_event(fd_set * fds);
void display_handle_key(unsigned int key);
int display_init();


#endif
