/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#ifndef NBEDUG

#include <stdio.h>

/*****************************************************************************
 *
 * dump_hex
 *
 * Dumps a memory area as hex on the screen.
 *
 * msg  - Info message for the dump
 * buf  - the memory buffer to dump
 * len  - length of the buffer
 *
 ****************************************************************************/

#define NIBBLE(_i)    (((_i) < 10) ? '0' + (_i) : 'A' + (_i) - 10)

void dump_hex(const unsigned char *buf, int addr, int len)
{
	const unsigned char *start;
	const unsigned char *pc;
	char *out;
	char c;
	char line[100];
	int i;
	int nlocal;

	start = buf;

	while (len > 0)
	{
		sprintf(line, "%08x: ", buf - start + addr);
		out = line + 10;

		for (i = 0, pc = buf, nlocal = len; i < 16; i++, pc++)
		{
			if (nlocal > 0)
			{
				c = *pc;

				*out++ = NIBBLE((c >> 4) & 0xF);
				*out++ = NIBBLE(c & 0xF);

				nlocal--;
			}
			else
			{
				*out++ = ' ';
				*out++ = ' ';
			}	/* end else */

			*out++ = ' ';
		}		/* end for */

		*out++ = '-';
		*out++ = ' ';

		for (i = 0, pc = buf, nlocal = len; (i < 16) && (nlocal > 0); i++, pc++, nlocal--)
		{
			c = *pc;

			if ((c < ' ') || (c >= 126))
			{
				c = '.';
			}

			*out++ = c;
		}		/* end for */

		*out++ = 0;

		fprintf(stdout, "%s\n", line);

		buf += 16;
		len -= 16;
	}			/* end while */
}				/* end dump */


#endif // #ifndef NDEBUG
