/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#include "keytab.h"

#include <string.h>

// These are the key codes as they are translated from a PC keyboard. I really
// don't understand how they work and noticed different results on different
// machines (e.g. for F2). If someone has a clue how to improve this code,
// PLEASE let me know at gnagflow@users.sourceforge.net.
//
// Thanks!
// 
static struct keytab_d
{
	char *buf;
	int key;
}
ktab[] =
{
	{ "\x1b\x5b\x41", KEY_UP},			// crsr-up
	{ "\x1b\x5b\x35\x7e", KEY_UP_10},		// page-up
	{ "\x1b\x5b\x42", KEY_DOWN},			// crsr-down
	{ "\x1b\x5b\x36\x7e", KEY_DOWN_10},		// page-down
	{ "\x1b\x5b\x43", KEY_RIGHT},			// crsr-right
	{ "\x1b\x5b\x44", KEY_LEFT},			// crsr-left
	{ "\x1b\x5b\x61", KEY_SHIFT_UP},		// SHIFT-crsr-up ???
	{ "\x1b\x5b\x62", KEY_SHIFT_DOWN},		// SHIFT-crsr-down ???
	{ "\x1b\x5b\x33\x7e", KEY_DELETE},
	{ "\x1b\x5b\x32\x7e", KEY_INSERT},
	{ "\x1b\x4f\x51", KEY_SESSION_MENU},		// F2 ???
	{ "\x1b\x5b\x31\x32\x7e", KEY_SESSION_MENU},	// F2 ???
	{ "\x1b\x5b\x31\x35\x7e", KEY_FILE_MENU},	// F5
	{ "\x1b\x5b\x31\x38\x7e", KEY_SEARCH_MENU},	// F7
	{ 0, 0}
};


int keytab_eval(const char *buf, unsigned int len)
{
	struct keytab_d *p;

	// check simple keys
	//
	if (1 == len)
	{
		switch (buf[0])
		{
		case 0x0d:	return KEY_SELECT;	// enter

//		case 0x2f:	return KEY_SEARCH;	// / for vi users
		case '#':	return KEY_SEARCH;

		case 0x7f:	return KEY_BACKSPACE;	// backspace
		case 0x1b:	return KEY_ESC;		// escape

		case '+':	return KEY_MARK;
		case '-':	return KEY_UNMARK;

		case '>':	return KEY_SESSION_MENU_NEXT;
		case '<':	return KEY_SESSION_MENU_PREV;

		case ']':	return KEY_SONG_PLAY_SUBDIR;

		case '\\':	return KEY_SONG_SELECT_PREVIOUS;

		case '!':	return KEY_PLAYLIST_MENU;

		case 0x03:	return KEY_EXIT;	// ctl-c
		}

		// no speacial key, pass along the code
		//
		return buf[0];
	}


	// No simple key. Go through the keytab table and check...
	//
	for (p = ktab; p->buf; p++)

	{
		// Using strcmp assumes that there are no 0x00 in the key code
		// (and that the incoming buffer is zero-terminated or at least
		// as long as the longest compare-buffer in ktab)...
		//
		if ((len == strlen(p->buf)) && (0 == strncmp(p->buf, buf, len)))
		{
			return p->key;
		}
	}

	return KEY_NONE;
}
