/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "search_menu.h"
#include "session_menu.h"
#include "playlist_menu.h"
#include "file_menu.h"
#include "tools.h"

#include "display.h"
#include "menu.h"
#include "info.h"
#include "player.h"
#include "util.h"

#include "main_menu.h"


/******************************************************************************/

static void play_from_hdd(void *data)
{
	display_push(menu_new_from_dir(DIR_MP3));
}


/******************************************************************************/

static void play_from_cd(void *data)
{
	char buf[MAX_PATH_LEN];

	display_push(info_new("Reading CDROM...", 0));
	display_show();

	sprintf(buf, "mount %s", DIR_CDROM);
	system(buf);
	display_pop();

	file_entry_list_cd_init();

	display_push(menu_new_from_dir(DIR_CDROM));
}


/******************************************************************************/

static void eject_cd(void *data)
{
	char buf[MAX_PATH_LEN];

	display_push(info_new("Ejecting CDROM...", 0));
	display_show();

	// Clear the file list for the CD
	//
	file_entry_list_cd_deinit();


	// We have to stop player, because the CD is busy while player is still
	// running and therefore can not be ejected.
	//
	player_shutdown();

	sprintf(buf, "umount %s", DIR_CDROM);
	system(buf);
	system("eject");
	display_pop();
}

/******************************************************************************/

static void play_from_usb(void *data)
{
	char buf[MAX_PATH_LEN];

	display_push(info_new("Reading USB-Stick...", 0));
	display_show();

	sprintf(buf, "mount %s", DIR_USB);
	system(buf);
	display_pop();

	file_entry_list_usb_init();

	display_push(menu_new_from_dir(DIR_USB));
}


/******************************************************************************/

static void remove_usb(void *data)
{
	char buf[MAX_PATH_LEN];

	display_push(info_new("Terminating USB-Stick...", 0));
	display_show();

	// Clear the file list for the CD
	//
	file_entry_list_cd_deinit();


	// We have to stop player, because the CD is busy while player is still
	// running and therefore can not be ejected.
	//
	player_shutdown();
	sleep(1);
	sprintf(buf, "umount %s", DIR_USB);
	system(buf);
	system("eject");
	display_pop();
	display_push(info_new("Please remove USB-Stick, then press OK.",0));
}


/******************************************************************************/

static void power_off(void *data)
{
	printf("\033[2J");
	printf("\033[H");
	system("shutdown -h now");
}


/******************************************************************************/

void main_menu()
{
	screen_t *main_menu = menu_new();

	menu_add(main_menu, "Play from harddisk", play_from_hdd);
	menu_add(main_menu, "Play from CDROM", play_from_cd);
	menu_add(main_menu, "Play from USB-Stick", play_from_usb);
	menu_add(main_menu, "Remove USB-Stick", remove_usb);
	menu_add(main_menu, "Eject CD", eject_cd);
//	menu_add(main_menu, "Playlist >> ", playlist_menu);
//	menu_add(main_menu, "Search   >>", search_menu);
//	menu_add(main_menu, "File     >>", file_menu);
//	menu_add(main_menu, "Session  >>", session_menu);
	menu_add(main_menu, "Extras", tools_menu);
	menu_add(main_menu, "Power OFF", power_off);


	display_push(main_menu);
}
