/****************************************************************************
 *
 *   Copyright (C) 2003, 2004 Wolfgang G. Reissnegger, All Rights Reserved
 *
 *   gnagflow@users.sourceforge.net                                    
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the license, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program;  if not, write to the
 *       Free Software Foundation, Inc.,
 *       59 Temple Place - Suite 330,
 *       Boston, MA 02111-1307
 *
 ****************************************************************************/

#ifndef PLAYER_H_
#define PLAYER_H_


// This structure is used by players to register their interface. Right now
// this is pretty much xxx123 based.
//
typedef struct player_if_d
{
	int	(*init)(void);
	void	(*exit)(void);

	int	(*fd)(void);

	void	(*play)(const char *path);
	int	(*stop)(void);
	int	(*pause)(void);
	void	(*fwd)(void);
	void	(*rew)(void);
	void	(*goto_frame)(int frame);

	int	(*recv_message)(void);
	int	(*current_frame)(void);
	int	(*sample_rate)(void);
	int	(*bit_rate)(void);

	int	(*is_playing)(void);
	int	(*is_paused)(void);
	int	(*has_ended)(void);

	const char *(*time)(void);
	const char *(*time_remaining)(void);
}
player_if_t;


/******************************************************************************/

int player_register(int file_type, player_if_t *interface);


/******************************************************************************/

void	player_shutdown();
int	player_fd();

void	player_play(const char *path, unsigned int type);
int	player_stop();
int	player_pause();
void	player_fwd();
void	player_rew();
void	player_goto_frame(int frame);

int	player_recv_message();

int	player_current_frame();
int	player_sample_rate();
int	player_bit_rate();

int	player_is_playing();
int	player_is_paused();
int	player_has_ended();

const char *player_time();
const char *player_time_remaining();

#endif
